@@ -9,7 +9,7 @@ package Rex::Repositorio::Server::Docker::Mojolicious::Plugin::DockerSession;
 use strict;
 use warnings;
 
-our $VERSION = '0.7.0'; # VERSION
+our $VERSION = '1.0.0'; # VERSION
 
 use Mojo::Base 'Mojolicious::Plugin';
 use Data::Dumper;
@@ -42,6 +42,7 @@ sub register {
             $self->stash( "session_token",         $session_id );
             $self->stash( "session_user",          $ref->{user} );
             $self->stash( "session_authenticated", 1 );
+            $self->stash( "upstream_docker_token", $ref->{upstream_docker_token} );
           }
         }
       }
@@ -65,7 +66,8 @@ sub register {
         print $fh encode_json(
           {
             token => $self->stash->{session_token},
-            user  => $self->stash->{session_user}
+            user  => $self->stash->{session_user},
+            upstream_docker_token => $self->stash->{'upstream_docker_token'} || '',
           }
         );
         close($fh);
