@@ -2,19 +2,29 @@ package Rex::Repositorio::Server::Helper::Proxy;
 
 use base 'Mojolicious::Plugin';
 
-our $VERSION = '0.7.0'; # VERSION
+our $VERSION = '1.0.0'; # VERSION
 
 sub register {
   my ( $self, $app ) = @_;
 
   $app->helper(
     proxy_to => sub {
-      my $c   = shift;
-      my $url = Mojo::URL->new(shift);
-      my $cb  = shift || sub { };
-      $c->inactivity_timeout(900); 
+      my $c       = shift;
+      my $url     = Mojo::URL->new(shift);
+      my $cb      = shift || sub { };
+      my $filter  = shift;
+      my $headers = shift || {};
 
-      my $ua  = $c->ua;
+      if ( $c->repo->{proxy} ne "true" ) {
+        $c->app->log->debug("No proxy support for this repository.");
+        $c->render( text => 'no proxy support', status => 500 );
+        return;
+      }
+
+      $c->inactivity_timeout(900);
+
+      my $ua = $c->ua;
+      $ua->max_redirects(5);
 
       if ( $c->repo->{ca} ) {
         $ua->ca( $c->repo->{ca} );
@@ -32,24 +42,28 @@ sub register {
       if ( Mojo::IOLoop->is_running ) {
         $c->render_later;
         $ua->get(
-          $url,
+          $url, $headers,
           sub {
             my ( $self, $tx ) = @_;
-            _proxy_tx( $c, $tx, $cb );
+            _proxy_tx( $c, $tx, $cb, $filter );
           }
         );
       }
       else {
-        my $tx = $ua->get($url);
-        _proxy_tx( $c, $tx, $cb );
+        my $tx = $ua->get( $url, $headers );
+        _proxy_tx( $c, $tx, $cb, $filter );
       }
     }
   );
 }
 
 sub _proxy_tx {
-  my ( $self, $tx, $cb ) = @_;
+  my ( $self, $tx, $cb, $filter ) = @_;
   if ( my $res = $tx->success ) {
+    if ( ref $filter eq "CODE" ) {
+      $filter->( $self, $tx );
+    }
+
     $self->tx->res($res);
     $self->rendered;
     $cb->( $self, $tx );
@@ -58,6 +72,12 @@ sub _proxy_tx {
     my $error = $tx->error;
     $self->tx->res->headers->add( 'X-Remote-Status',
       $error->{code} . ': ' . $error->{message} );
+    $self->app->log->error( "Error during proxy request: ("
+        . $error->{code} . ") "
+        . $error->{message}
+        . " [url: "
+        . $tx->req->url
+        . "]" );
     $self->render( status => 500, text => 'Failed to fetch data from backend' );
   }
 }
